@@ -26,6 +26,8 @@ class ChecksumGenerator(object):
         return day + month + year
 
     def _clave_to_bytearray(self, clave: str) -> bytearray:
+        if not clave:
+            clave = ''
         return int.to_bytes(int(clave), 4, 'big')
 
     def _monto_to_bytearray(self, amount: int) -> bytearray:
