@@ -28,6 +28,18 @@ class TipoPagoOrdenPago(str, Enum):
     cobros_no_presenciales_a_nombre_de_tercero = '22'
     devolucion_especial_acreditada = '23'
     devolucion_extemporanea_especial_acreditada = '24'
+    tercero_a_tercero_fsw_cls = '25'
+    tercero_a_tercero_vostro_fsw_cls = '26'
+    participante_a_tercero_fsw_cls = '27'
+    participante_a_tercero_vostro_fsw_cls = '28'
+    participante_a_participante_fsw_cls = '29'
+    tercero_indirecto_a_tercero = '30'
+    tercero_indirecto_a_participante = '31'
+    presencial_de_una_ocasion_indirecto = '32'
+    no_presencial_de_una_ocasion_indirecto = '33'
+    no_presencial_recurrente_indirecto = '34'
+    remesa_saliente = '35'
+    remesa_entrante = '36'
 
 
 class TipoOrdenPago(str, Enum):
@@ -104,6 +116,20 @@ class MedioEntregaOrdenPago(str, Enum):
     ifai = '13'
     swift = '17'
     nomina = '18'
+    threats = '19'
+    ghss = '20'
+    nts = '21'
+    continuous_linked_settlement = '23'
+    depto = '24'
+    another_ghss = '25'
+    cp = '26'
+    cpn = '27'
+    opee = '28'
+    pagos_md = '29'
+    pib = '31'
+    summit = '32'
+    devext = '33'
+    int = '99'
 
 
 class TopologiaOrdenPago(str, Enum):
@@ -115,16 +141,27 @@ class TipoDevolucionOrdenPago(str, Enum):
     account_not_found = 1
     account_blocked = 2
     account_canceled = 3
+    wrong_account_currency = 5
     account_number_is_not_fondea = 6
+    beneficiary_e_firma_revoked = 11
+    beneficiary_unrecognized_payment = 13
     missing_required_data = 14
     invalid_payment_type = 15
     invalid_operation_type = 16
     invalid_account_type = 17
+    requested_by_origin = 18
     invalid_character = 19
     autorized_limit_exceeded = 20
     deposit_limit_exceeded = 21
+    phone_not_registered = 22
+    additional_account_can_not_receive_payments = 23
+    payment_information_malformed = 24
+    missing_dispersion_instruction = 25
+    resolution_not_approved_by_origin = 26
     invalid_optional_payment_type = 27
+    codi_payment_notification_timeout = 28
     duplicated_tracking_code = 30
+    origin_institution_certificate_expired = 31
 
 
 CodigoError = generate_error_codes()
